@@ -38,7 +38,7 @@
 
 #ifndef lint
 #ifdef	DOSCCS
-static char sccsid[] = "@(#)cmd3.c	2.85 (gritter) 6/16/07";
+static char sccsid[] = "@(#)cmd3.c	2.86 (gritter) 10/1/07";
 #endif
 #endif /* not lint */
 
@@ -324,6 +324,7 @@ followupsender(void *v)
 static int 
 respond_internal(int *msgvec, int recipient_record)
 {
+	int Eflag;
 	struct message *mp;
 	char *cp, *rcv;
 	enum gfield	gf = value("fullnames") ? GFULL : GSKIN;
@@ -364,7 +365,8 @@ respond_internal(int *msgvec, int recipient_record)
 		head.h_cc = np;
 	}
 	make_ref_and_cs(mp, &head);
-	if (mail1(&head, 1, mp, NULL, recipient_record, 0, 0) == OKAY &&
+	Eflag = value("skipemptybody") != NULL;
+	if (mail1(&head, 1, mp, NULL, recipient_record, 0, 0, Eflag) == OKAY &&
 			value("markanswered") && (mp->m_flag & MANSWERED) == 0)
 		mp->m_flag |= MANSWER|MANSWERED;
 	return(0);
@@ -401,6 +403,7 @@ reedit(char *subj)
 static int
 forward1(char *str, int recipient_record)
 {
+	int Eflag;
 	int	*msgvec, f;
 	char	*recipient;
 	struct message	*mp;
@@ -450,8 +453,9 @@ forward1(char *str, int recipient_record)
 	if ((head.h_subject = hfield("subject", mp)) == NULL)
 		head.h_subject = hfield("subj", mp);
 	head.h_subject = fwdedit(head.h_subject);
+	Eflag = value("skipemptybody") != NULL;
 	mail1(&head, 1, forward_as_attachment ? NULL : mp,
-			NULL, recipient_record, 1, 0);
+			NULL, recipient_record, 1, 0, Eflag);
 	return 0;
 }
 
@@ -953,6 +957,7 @@ Followup(void *v)
 static int 
 Respond_internal(int *msgvec, int recipient_record)
 {
+	int Eflag;
 	struct header head;
 	struct message *mp;
 	enum gfield	gf = value("fullnames") ? GFULL : GSKIN;
@@ -976,7 +981,8 @@ Respond_internal(int *msgvec, int recipient_record)
 		head.h_subject = hfield("subj", mp);
 	head.h_subject = reedit(head.h_subject);
 	make_ref_and_cs(mp, &head);
-	if (mail1(&head, 1, mp, NULL, recipient_record, 0, 0) == OKAY &&
+	Eflag = value("skipemptybody") != NULL;
+	if (mail1(&head, 1, mp, NULL, recipient_record, 0, 0, Eflag) == OKAY &&
 			value("markanswered") && (mp->m_flag & MANSWERED) == 0)
 		mp->m_flag |= MANSWER|MANSWERED;
 	return 0;
